﻿# "This is a template and example of configuration file for Sim::OPT.

$mypath = "/home/luca/tp" ;# path of the directory in which you are going to work
##@sweeps = ( [ [ 1 ] ] );
#@sweeps = ( [ [ 1, 2, 3, 4 ] ] );
#@sweeps = ( [ [ 1, 2, 3], [2, 3, 4] , [ 3, 4, 5], [4, 5, 6 ] ] );
@sweeps = ( [ [ 1, 2, 3, 4, 5, 6, 7 ] ] );
#@sweeps = ( [ [ 1 ] ] );
# OR: ( [ [1, 2], [2, 3] ] ); # OR: @sweeps = ( [ [1, 2, 3, 4], [3, 4, 5, 1], [5, 1, 2, 3] ], [ [1, 2], [2, 3] ] ); # OR: @sweeps = ( [ [1, 2, 3, 4], [3, 4, 5, 1], [5, 1, 2, 3] ] );
# DESCRIPTION OF A (MAYBE OVERLAPPING) COORDINATE BLOCK DESCENT. # THE NUMBERS ARE THE VARIABLE NUMBERS.
# MORE THAN ONE SEARCH MAY BE LISTED. # EACH BLOCK SEARCH IS DESCRIBED AS A SEQUENCE OF LIST VARIABLES.
# THIS IS THE BLOCK SEARCH STRUCTURE DECLARED EXPLICITLY AS AN ALTERNATIVE TO USING @chanceseed AND @caseseed.
# IF BOTH @sweeps AND THOSE TWO VARIABLES ARE SPECIFIED, 
# @sweeps IS NOT OVERRIDDEN ON THE BASIS OF WHAT IS SPECIFIED IN @chanceseed AND @caseseed. 
# IT HAS TO BE UNSPECIFIED IF THE SEARCH STRUCTURE HAS TO BE CALCULATE BY THE PROGRAM. @sweepseed MAY BE SPECIFIED IN ITS PLACE.

##@varinumbers = ( { 1 => 2 } );
#@varinumbers = ( { 1 => 3, 2 => 3, 3 => 3, 4 => 3 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
#@varinumbers = ( { 1 => 3, 2 => 3, 3 => 3, 4 => 3, 5 => 3, 6 => 3 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
@varinumbers = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 4, 7 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
#@varinumbers = ( { 1 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS'
# OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' } ); # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' }, { 1 => '3', 2 => '3', 3 => '3' } );
# IN THIS ARRAY OF HASHES (DICTIONARIES) THE NUMBER OF ITERATIONS FOR EACH VARIABLES ARE SPECIFIED.

#@mediumiters = ( { 1 => 1, 2 => 2 } );
#@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2 } );
#@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 2 } );
##@mediumiters = ( { 1 => 1  } );
@mediumiters = ( { 1 => 1, 2 => 1, 3 => 1, 4 => 1, 5 => 1, 6 => 2, 7 => 1 } ); # OR: @mediumiters = ( { 1 => 2, 2 => 2, 3 => 2 } );
#@mediumiters = ( { 1 => 1 } ); # OR: @mediumiters = ( { 1 => 2, 2 => 2, 3 => 2 } );
# IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
# IF LEFT UNSPECIFIED IT DEFAULTS TO THE MIDDLE ITERATION FOR EACH VARIABLE.  # IF LEFT UNSPECIFIED IT DEFAULTS TO THE CENTRAL VALUE FOR EACH GIVEN RANGE. 

$file = "tp";  # the root model directory.

%dowhat = ( # This variables tells to the program what to do.
morph => "y", # create cases for simulation?
simulate => "n", # simulate AND retrieve? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
retrieve => "n",  # retrieve data? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
report => "n",  # retrieve data? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
descend => "n", # descend into results? THIS MUST BE "y" FOR BLOCK SEARCH.
eraseres => "n", # erase .res and .fl files as they are created or leave them as traces?
substitutenames => "n", # substitute names (convert) in non-filtered reports? (UNTESTED SINCE EARLY VERSIONS.)
filterconverted => "n", # filter already converted reports? (UNTESTED SINCE EARLY VERSIONS.)
make3dtable => "n", # make table to be plotted in 3D? (UNTESTED SINCE EARLY VERSIONS.)
overwrite_models => { 1 => "n" },
inactivatemorph => "n",
inactivatesim => "n",
inactivateres => "n",
incativateret => "n",
simtools => { 1 => "energyplus", 
#2 => "esp-r" 
},
); # 11) THIS MUST BE "y" TO PERFORM BLOCK SEARCH. It checks if it is possible to launch a block search, and if it is does it.

$fileconfig = "newbox21.idf"; # name of the configuration file of the model.

$simnetwork = "n"; # is there a mass/flow network? This information regards the simulation settings.
$exeonfiles = "y";
$preventsim = "n";

$simtitles{1} = [ # TRANSFORMATIONS TO BE DONE TO AN .idf FILE BEFORE LAUNCHING A SIMULATION
[ "epannual", "1 1", "12 31", "20", "1", "milan.epw", "/ep", "newbox21.idf", "", "", ".idf", ".eso" ], 
]; # [ "name", "begin_date", "end_date", "warmup_days", "timestep", "climatefile", "epfile_directory", "epfile_name", "distinctive_part_of_name", "output_directory", ".config_file_type", ".output_file_type" ]

#$vals{1}{skipsim} = " ( ( $to =~ /_1-2/ ) or ( $to =~ /_2-2/ ) or ( $to =~ /_3-2/ ) or ( $to =~ /_4-2/ ) or ( $to =~ /_5-2/ ) or ( $to =~ /_6-2/ ) ) ";
#$vals{1}{skipsim} = " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-3/ ) or ( \$to =~ /_6-5/ ) ) ";

$retrievedata{1} = 
[ 
[ 
[ 
"1 1 1", "31 12 24", "1" 
] 
]
]; 


# OR: ( [["1 3 1", "31 3 24", "1"] , ["1 3 1", "31 3 24", "1"]], [["1 4 1", "30 4 24", "1"] , ["1 4 1", "30 4 24", "1"]] ); 
# start data to retrieve for temps; end data to retrieve for temps.
# THESE ARE THE PERIODS TO BE REPORTED. THERE IS A POINT TO POINT CORRESPONDENCE WITH @reporttiles

#@weights = 
#( 
#0.5, 0.5
#); 
# RATIO OF EACH OBJECTIVE FUNCTION, OVER THE TOTAL OF 1.

#@weightsaim = (
#1, -1
#); 
# THERE IS A POINT TO POINT CORRENSPONDENCE WITH THE ABOVE ARRAY. A (-1) VALUE TELLS THE PROGRAM THAT THE OBJECTIVE FOR THAT OBJECTIVE FUNCTION IS MINIMIZATION. 
# A (+1) VALUE TELLS THE PROGRAM THAT THE OBJECTIVE IS MAXIMIZATION. 

#@varthemes_report = (
#"something", "something_else1","something_else2", "something_else3"
#); ########## Definitions that are going to substitute the variable numbers in the tables. (THIS OPERATION MAY BE UNUSED.)

#@varthemes_variations = (
#[-1, 1], [-1, 1],[-36, 36] , [-30, 30],[-30, 30],[-30, 30],[-30, 30], [-1, 1]
#); ######### Minimum and maximum values regarding the variables, in the same order above. (THIS OPERATION MAY BE UNUSED.)

#@varthemes_steps = (
#5, 5, 5, 5, 5
#);  ######### Number of steps allowed for each variables. In the same order above. (NOTE: THIS OPERATION MAY BE UNUSED.)

#@rankdata = ( # CUT ZZZ
#"n", "n", "y", "n"
#); # THIS DATA ARE POINT-TO- POINT RELATIVE TO THE ARRAY ABOVE AND TELL WHAT FIELD THE RANKING HAS TO BE BASED ON

#@rankcolumn = (
#0, 0, 3, 0
#); # THIS DATA ARE POINT-TO- POINT RELATIVE TO THE ARRAY ABOVE AND TELLS WHAT FILE COLUMN THE RANKING HAS TO BE BASED ON: 3 for max air temps, 5 for min air temps, 7 for mean air temps, 8 for resultant max temps, 10 for resultant min temps, 12 for resultant mean temps - # (NOTE: UNMANTAINED FROM VERSION 0.5 ON).

$reportdata{1} = # THERE IS A POINT-TO POINT CORRESPONDENCE TO THE ITEMS IN @retrievedata
[ 
[ 
[ 
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmrad_monthly-jan", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 1,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 2, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "7,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => "",
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmheat_monthly-jan", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 1,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 2, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "13,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "restemp_monthly-jan", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 1,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 2, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "35,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
]
],
[ 
[ 
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmrad_monthly-feb", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 2,28, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 3, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "7,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmheat_monthly-feb", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 2,28, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 3, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "13,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "restemp_monthly-feb", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 2,28, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 3, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "35,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
]
],
[ 
[ 
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmrad_monthly-mar", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 3,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 4, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "7,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmrad_hourly-mar", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 3,15, 0, 1, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 3,17, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "6,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmheat_monthly-mar", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 3,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 4, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "13,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmheat_hourly-mar", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 3,15, 0, 1, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 3,17, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "12,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "restemp_monthly-mar", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 3,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 4, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "35,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "restemp_hourly-mar", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 3,15, 0, 1, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 3,17, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "34,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
]
],
[ 
[ 
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmrad_monthly-apr", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 4,30, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 5, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "7,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmheat_monthly-apr", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 4,30, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 5, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "13,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "restemp_monthly-apr", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 4,30, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 5, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "35,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
]
],
[ 
[ 
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmrad_monthly-may", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 5,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 6, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "7,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmheat_monthly-may", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 5,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 6, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "13,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "restemp_monthly-may", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 5,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 6, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "35,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
]
],
[ 
[ 
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmrad_monthly-jun", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 6,30, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 7,01, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "7,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmrad_hourly-jun", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 6,15, 0, 1, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 6,17, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "6,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmheat_monthly-jun", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 6,30, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 7,01, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "13,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmheat_hourly-jun", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 6,15, 0,01, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 6,17, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "12,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "restemp_monthly-jun", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 6,30, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 7,01, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "35,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "restemp_hourly-jun", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 6,15, 0, 1, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 6,17, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "34,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
]
],
[ 
[ 
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmrad_monthly-jul", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 7,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 8, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "7,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmheat_monthly-jul", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 7,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 8, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "13,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "restemp_monthly-jul", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 7,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 8, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "35,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
]
],
[ 
[ 
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmrad_monthly-aug", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 8,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 9, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "7,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmheat_monthly-aug", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 8,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 9, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "13,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "restemp_monthly-aug", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 8,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ", 9, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "35,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
]
],
[ 
[ 
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmrad_monthly-sep", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 9,30, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ",10, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "7,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmheat_monthly-sep", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 9,30, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ",10, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "13,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "restemp_monthly-sep", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ", 9,30, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ",10, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "35,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
]
],
[ 
[ 
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmrad_monthly-oct", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ",10,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ",11, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "7,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmheat_monthly-oct", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ",10,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ",11, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "13,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "restemp_monthly-oct", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ",10,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ",11, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "35,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
]
],
[ 
[ 
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmrad_monthly-nov", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ",11,30, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ",12, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "7,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmheat_monthly-nov", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ",11,30, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ",12, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "13,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "restemp_monthly-nov", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ",11,30, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ",12, 1, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "35,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
]
],
[ 
[ 
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmrad_monthly-dec", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ",12,31, 0,24, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => "", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "7,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmrad_hourly-dec", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ",12,15, 0, 1, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ",12,17, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "6,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmheat_monthly-dec", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ",12,31, 0, 1, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => "", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "13,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "wintrasmheat_hourly-dec", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ",12,15, 0, 1, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ",12,17, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "12,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "restemp_monthly-dec", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ",12,31, 0, 1, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => "", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "35,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
	{
		reporttitle => "", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
		themereport => "restemp_hourly-dec", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
		semaphorego1 => ",12,15, 0, 1, 0.00,60.00,", # SEMAPHORE 1 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorego2 => "", # SEMAPHORE 2 ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
		semaphorestop1 => ",12,17, 0, 1, 0.00,60.00,", # SEMAPHORE 1 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		semaphorestop2 => "", # SEMAPHORE 2 OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
		textpattern => "34,", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
		afterlines => ""
	},
]
],
];


#$vals{skipfile} = "skipfile.txt";
#$vals{skipreport} = " ( ( $simtitle =~ /_1-2/ ) or ( $simtitle =~ /_2-2/ ) or ( $simtitle =~ /_3-2/ ) or ( $simtitle =~ /_4-2/ ) or ( $simtitle =~ /_5-2/ ) or ( $simtitle =~ /_6-2/ ) ) ";
#$vals{skipreport} = " ( ( \$simtitle =~ /_1-2/ ) or ( \$simtitle =~ /_2-2/ ) or ( \$simtitle =~ /_3-2/ ) or ( \$simtitle =~ /_4-2/ ) or ( \$simtitle =~ /_5-2/ ) or ( \$simtitle =~ /_6-3/ ) or ( \$simtitle =~ /_6-5/ )) ";

#@keepcolumns = ( 
#[ "min res_temp", 2 ], [ "avg res_temp", 4 ], [ "max res_temp", 6 ], [ "radiation entering zone", 8 ], 
#[ "radiation transmitted through transparent surfaces", 9 ], [ "radiation absorbed by the zone", 10 ], 
#); 
# COLUMNS TO KEEP FROM THE FILE OF RESULTS. THEY ARE WRITTEN IN PAIRS. 
# THE FIRST ITEM OF EACH PAIR IS THE OBJECTIVE FUNCTION NAME AND THE SECOND IS THE COLUMN TO KEEP 
# FROM THE RESULT FILE AND BRING TO THE RESULT SUMMARY.


########### VARIABLES OF SECONDARY IMPORTANCE - ABOUT REPORTING ##############

#@files_to_filter = ("wholenew", "1-2var", "2-3var", 
#"3-4var", "4-5var", "1-3var", 
#"2-4var", "3-5var", "1-4var",
#"2-5var", "1-5var",);
#@filter_reports = ( [ [ 2, 3, 4, 5, 1] ],  [ [1, 2] , [3, 4, 5] , [5, 5, 5], [18]],   [ [2, 3] , [1, 4, 5] , [5, 5, 5], [18]],
#[ [3, 4] , [1, 2, 5] , [5, 5, 5], [18]], [ [4, 5] , [1, 2, 3] , [5, 5, 5], [18]], [ [1, 3] , [2, 4, 5] , [5, 5, 5], [18]],
#[ [2, 4] , [1, 3, 5] , [5, 5, 5], [18]], [ [3, 5] , [5, 5, 5] , [1, 1, 1], [18]], [ [1, 4] , [2, 3, 5] , [5, 5, 5], [18]],
#[ [2, 5] , [1, 3, 4] , [5, 5, 5], [18]], [ [1, 5] , [2, 3, 4] , [5, 5, 5], [18]]
 # ) ; # for the first [] element: a list of all the variables number; from the second on: varnumbers to report, varnumbers not to report, 
#  # casenumber to report among varnumbers not to report, column to extract from tables.
#@base_columns = ([], [0, 1, 18], [1, 2, 18], 
#[2, 3, 18], [3, 4, 18], [0, 2, 18], 
#[1, 3, 18], [2, 4, 18], [0, 3, 18],
#[1, 4, 18], [0, 4, 18]); #position of the columns to select to be put in the table in the maketable subroutine. THE ORDER IS: COLUMN, ROW, VALUE in the table to be obtained. ALWAYS THE COLUMN THAT IS BEFORE IN THE TABLE HAS TO BE USED AS ROW.
#@maketabledata = ([], [5, 5], [5, 5], 
#[5, 5], [5, 5], [5, 5], 
#[5, 5], [5, 5], [5, 5],
#[5, 5], [5, 5]); # THIS VALUES REGARD THE ORDER ABOVE, STARTING FROM THE FIRST GROUP (THAT IS, FROM THE SECOND POSITION) TO THE SECOND GROUP. THE FIRST POSITION HAS TO BE LEFT BLANK: []!
#@filter_columns = (0, 1, 2, 3, 4, 19, 20, 21); #THIS IS OF THE GREATEST IMPORTANCE: (0, 1, 2, 3, 4, 5, 9, 11, 13, 14, 16, 18, 19, 20), IS RIGH FOR TEMPSTASTS. (0, 1, 2, 3, 4, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21); THE LAST COLUMN MUST ALWAYS BE IN, PLUS ONE MORE.

################################################################################
################# MORPHING PARAMETERS ###################

######################### PARAMETER 1. #############################


$vals{1}{1}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
# the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
# "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
# "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
$vals{1}{1}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
[ #BRACKET FOR GROUP
[ #BRACKET FOLLOWING THE @applype BRACKETS. EACH BRACKET IS A SEQUENCE OF OPEARATION TO BE MADE IN PARALLEL. HERE THERE IS JUST ONE SEQUENCE.
[  ], # EXAMPLE: [ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ] THESE CAN BE ABSENT. IN THAT CASE, PUT: [] (EMPTY BARACKETS. THESE ARE ONE OR MORE FILES IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file". 
[ # BRACKET DELIMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
[ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
"/ep/newbox21.idf", # FILE TO BE MODIFIED.
#[ [ 19 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
[ [ 19, 20, 21, 22, 34, 35, 66, 67, 79, 82, 95, 96 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
[ 2 ], [ 0, -1.5 ], [  ], "linear", ",", 5  ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type("linear"_or_"rotation2d"_or_"wordchange"_), "separator"(e.g. "," - optional), precision(number_of_decimals) ]; # IF "wordchange" IS SPECIFIED, THE LIST OF WORDS TO BE PUT IN PLACE OF THE CHOSEN ITEM(S) MUST BE PLACED IN THE SAME SQUARE BRAKETS THAT FOR  OTHER CHANGE_TYPES ARE USED FOR THE max & min VALUES. 
]
]
]
];


$vals{1}{2}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
# the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
# "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
# "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
$vals{1}{2}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
[ #BRACKET FOR GROUP
[ #BRACKET FOLLOWING THE @applype BRACKETS. EACH BRACKET IS A SEQUENCE OF OPEARATION TO BE MADE IN PARALLEL. HERE THERE IS JUST ONE SEQUENCE.
[  ], # EXAMPLE: [ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ] THESE CAN BE ABSENT. IN THAT CASE, PUT: [] (EMPTY BARACKETS. THESE ARE ONE OR MORE FILES IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file". 
[ # BRACKET DELEMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
[ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
"/ep/newbox21.idf", # FILE TO BE MODIFIED.
[ [ 199, 200, 201, 202, 214, 215, 246, 247, 259, 262, 275, 276 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
[ 2 ], [ 0, -1.5 ], [  ], "linear", ",", 5  ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type("linear"_or_"rotation2d"_or_"wordchange"_), "separator"(e.g. "," - optional), precision(number_of_decimals) ]; # IF "wordchange" IS SPECIFIED, THE LIST OF WORDS TO BE PUT IN PLACE OF THE CHOSEN ITEM(S) MUST BE PLACED IN THE SAME SQUARE BRAKETS THAT FOR  OTHER CHANGE_TYPES ARE USED FOR THE max & min VALUES. 
]
]
]
];

$vals{1}{3}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
# the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
# "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
# "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
$vals{1}{3}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
[ #BRACKET FOR GROUP
[ #BRACKET FOLLOWING THE @applype BRACKETS. EACH BRACKET IS A SEQUENCE OF OPEARATION TO BE MADE IN PARALLEL. HERE THERE IS JUST ONE SEQUENCE.
[  ], # EXAMPLE: [ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ] THESE CAN BE ABSENT. IN THAT CASE, PUT: [] (EMPTY BARACKETS. THESE ARE ONE OR MORE FILES IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file". 
[ # BRACKET DELEMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
[ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
"/ep/newbox21.idf", # FILE TO BE MODIFIED.
[ [ 289, 290, 291, 292, 304, 305, 336, 337, 349, 352, 365, 366 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
[ 2 ], [ 0, -1.5 ], [  ], "linear", ",", 5  ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type("linear"_or_"rotation2d"_or_"wordchange"_), "separator"(e.g. "," - optional), precision(number_of_decimals) ]; # IF "wordchange" IS SPECIFIED, THE LIST OF WORDS TO BE PUT IN PLACE OF THE CHOSEN ITEM(S) MUST BE PLACED IN THE SAME SQUARE BRAKETS THAT FOR  OTHER CHANGE_TYPES ARE USED FOR THE max & min VALUES. 
]
]
]
];

$vals{1}{4}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
# the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
# "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
# "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
$vals{1}{4}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
[ #BRACKET FOR GROUP
[ #BRACKET FOLLOWING THE @applype BRACKETS. EACH BRACKET IS A SEQUENCE OF OPEARATION TO BE MADE IN PARALLEL. HERE THERE IS JUST ONE SEQUENCE.
[  ], # EXAMPLE: [ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ] THESE CAN BE ABSENT. IN THAT CASE, PUT: [] (EMPTY BARACKETS. THESE ARE ONE OR MORE FILES IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file". 
[ # BRACKET DELEMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
[ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
"/ep/newbox21.idf", # FILE TO BE MODIFIED.
[ [ 379, 380, 381, 382, 394, 395, 426, 427, 439, 442, 455, 456 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
[ 2 ], [ 0, -1.5 ], [  ], "linear", ",", 5  ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type("linear"_or_"rotation2d"_or_"wordchange"_), "separator"(e.g. "," - optional), precision(number_of_decimals) ]; # IF "wordchange" IS SPECIFIED, THE LIST OF WORDS TO BE PUT IN PLACE OF THE CHOSEN ITEM(S) MUST BE PLACED IN THE SAME SQUARE BRAKETS THAT FOR  OTHER CHANGE_TYPES ARE USED FOR THE max & min VALUES. 
]
]
]
];

$vals{1}{5}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
# the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
# "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
# "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
$vals{1}{5}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
[ #BRACKET FOR GROUP
[ #BRACKET FOLLOWING THE @applype BRACKETS. EACH BRACKET IS A SEQUENCE OF OPEARATION TO BE MADE IN PARALLEL. HERE THERE IS JUST ONE SEQUENCE.
[  ], # EXAMPLE: [ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ] THESE CAN BE ABSENT. IN THAT CASE, PUT: [] (EMPTY BARACKETS. THESE ARE ONE OR MORE FILES IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file". 
[ # BRACKET DELEMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
[ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
"/ep/newbox21.idf", # FILE TO BE MODIFIED.
[ [ 109, 112, 124, 127, 139, 142, 154, 157, 169, 170, 171, 172 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
[ 3 ], [ 0, 4 ], [  ], "linear", ",", 5  ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type("linear"_or_"rotation2d"_or_"wordchange"_), "separator"(e.g. "," - optional), precision(number_of_decimals) ]; # IF "wordchange" IS SPECIFIED, THE LIST OF WORDS TO BE PUT IN PLACE OF THE CHOSEN ITEM(S) MUST BE PLACED IN THE SAME SQUARE BRAKETS THAT FOR  OTHER CHANGE_TYPES ARE USED FOR THE max & min VALUES. 
]
]
]
];


$vals{1}{6}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
# the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
# "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
# "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
$vals{1}{6}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
[ #BRACKET FOR GROUP
[ #BRACKET FOLLOWING THE @applype BRACKETS. EACH BRACKET IS A SEQUENCE OF OPEARATION TO BE MADE IN PARALLEL. HERE THERE IS JUST ONE SEQUENCE.
[  ], # EXAMPLE: [ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ] THESE CAN BE ABSENT. IN THAT CASE, PUT: [] (EMPTY BARACKETS. THESE ARE ONE OR MORE FILES IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file". 
[ # BRACKET DELEMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
[ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
"/ep/newbox21.idf", # FILE TO BE MODIFIED.
[ [ 19, 20, 21, 22, 34, 35, 36, 37, 49, 50, 51, 52, 64, 65, 66, 67, 79, 80, 81, 82, 94, 95, 96, 97,
109, 110, 111, 112, 124, 125, 126, 127, 139, 140, 141, 142, 154, 155, 156, 157, 169, 170, 171, 172, 184, 185, 186, 187,
199, 200, 201, 202, 214, 215, 216, 217, 229, 230, 231, 232, 244, 245, 246, 247, 259, 260, 261, 262, 274, 275, 276, 277,
289, 290, 291, 292, 304, 305, 306, 307, 319, 320, 321, 322, 334, 335, 336, 337, 349, 350, 351, 352, 364, 365, 366, 367,
379, 380, 381, 382, 394, 395, 396, 397, 409, 410, 411, 412, 424, 425, 426, 427, 439, 440, 441, 442, 454, 455, 456, 457,
490, 491, 492, 493, 506, 507, 508, 509, 522, 523, 524, 525, 538, 539, 540, 541, 554, 555, 556, 557, 570, 571, 572, 573, 586, 587, 588, 589 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
[ 1, 2 ], [ -90, 180 ], [  ], "rotation2d", ",", 5, [ 0, 0 ] ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type("linear"_or_"rotation2d"_or_"wordchange"_), "separator"(e.g. "," - optional), precision(number_of_decimals) ]; # IF "wordchange" IS SPECIFIED, THE LIST OF WORDS TO BE PUT IN PLACE OF THE CHOSEN ITEM(S) MUST BE PLACED IN THE SAME SQUARE BRAKETS THAT FOR  OTHER CHANGE_TYPES ARE USED FOR THE max & min VALUES. 
]
]
]
];

$vals{1}{7}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
# the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
# "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
# "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
$vals{1}{7}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
[ #BRACKET FOR GROUP
[ #BRACKET FOLLOWING THE @applype BRACKETS. EACH BRACKET IS A SEQUENCE OF OPEARATION TO BE MADE IN PARALLEL. HERE THERE IS JUST ONE SEQUENCE.
[  ], # EXAMPLE: [ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ] THESE CAN BE ABSENT. IN THAT CASE, PUT: [] (EMPTY BARACKETS. THESE ARE ONE OR MORE FILES IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file". 
[ # BRACKET DELEMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
[ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
"/ep/newbox21.idf", # FILE TO BE MODIFIED.
[ [ 741 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
[ 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13 ], [ 0, 0.6 ], [  ], "linear", ",", 5 ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type("linear"_or_"rotation2d"_or_"wordchange"_), "separator"(e.g. "," - optional), precision(number_of_decimals) ]; # IF "wordchange" IS SPECIFIED, THE LIST OF WORDS TO BE PUT IN PLACE OF THE CHOSEN ITEM(S) MUST BE PLACED IN THE SAME SQUARE BRAKETS THAT FOR  OTHER CHANGE_TYPES ARE USED FOR THE max & min VALUES. 
]
]
]
];




#############################################################################################
# $target = "opt"; # THIS VARIABLE DEFINES THE MODULE TO WHICH THE DATA IN THIS CONFIGURATION FILE ARE AIMED.
# THE POSSIBILITIES ARE: "opt" FOR "Sim::OPT" (ESP-r-specific), or "takechance" FOR "Sim::OPT::Takechance".
# IF UNSPECIFIED, IT DEFAULTS TO "opt".
#
##@caseseed =
##( 
##[ 
##[0, 4], [2, 4] , [4, 4],
##]
##,
##[
##[0, 2], [1, 2]
##]
##) ;  
## OPTIONAL. THIS AND @chanceseed SUPERSEDE @sweeps. 
## IT IS A WAY TO DESCRIBE THE SAME THING: THE STRUCTURE OF A (MAYBE OVERLAPPING) COORDINATE BLOCK DESCENT. 
## THIS IS THE ORDER OR PARAMETERS AT EACH SEARCH SWEEP. THERE IS A POINT TO POINT CORRESPONDENCE WITH @chanceseed.
## BETWEEN SQUARE BRACKETS ARE THE BLOCKS OF THE BLOCK COORDINATE SEARCH. THE FIRST ITEM IN 
## EACH SQUARE BRACKET IS THE POSITION OF THE FIRST ITEM IN THE ACTIVE BLOCK (INDEX FROM 0). 
## THE SECOND ITEM IS THE DIMENSION OF THE ACTIVE BLOCK, IN TERMS OF NUMBER OF PARAMETERS.
#
##@chanceseed = 
##(
##[
##[1, 2, 3, 4, 5], [1, 2, 3, 4, 5] , [1, 2, 3, 4, 5]
##]
##, 
##[
##[1, 2, 3], [1, 2, 3]
##]
##);
## OPTIONAL. THIS AND @caseseed SUPERSEDE @sweeps. 
## IT IS A WAY TO DESCRIBE THE SAME THING: THE STRUCTURE OF A (MAYBE OVERLAPPING) COORDINATE BLOCK DESCENT. 
## THIS IS THE ORDER OR PARAMETERS AT EACH SEARCH SWEEP. THERE IS A POINT TO POINT CORRESPONDENCE WITH @chanceseed.
## EACH OF THIS SERIES IS REFERRED TO THE CORRESPONDING BLOCK IN THE SAME POSITION OF THE $casefile.
## THESE SERIES SPECIFY THE ORDER OF PARAMETERS TO BE DECOMPOSED. THE DECOMPOSITION IS THAT SPECIFIED 
## IN $caseseed. 
#
##@chancedata = 
##([4, 2, 1], [3, 2, 1]); 
## HERE: 1) BLOCK LENGTH OF BLOCKS TO ADD; 2) OVERLAP BETWEEN BLOCKS; 3) NUMBER OF SWEEPS TO ADD.
## UNUSED FOR THE MOMENT.
#
##$dimchance =
##3;
## THIS IS USED IF $generatechance IS "y". IT TELLS TO THE PROGRAM AMONG HOW MANY RANDOM TRIALS THE COMBINATION 
## THAT WILL END UO BEING USED HAS TO BE SELECTED.






